"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStartUrl = exports.generateMetaTitleOptions = exports.generateMetaDescriptionOptions = exports.generateManifest = exports.generateIcons = exports.generateBrand = exports.default = exports.Manifest = void 0;

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactHelmet = require("react-helmet");

var _q3UiHelpers = require("q3-ui-helpers");

var _useSiteMetaData = _interopRequireDefault(require("./useSiteMetaData"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const withContent = output => content => content && (0, _lodash.isFunction)(output) ? output(content) : [];

const getStartUrl = () => _q3UiHelpers.browser.isBrowserReady() ? (0, _lodash.get)(window, 'location.host') : '';

exports.getStartUrl = getStartUrl;
const generateMetaDescriptionOptions = withContent(content => [{
  name: 'description',
  content
}, {
  property: 'og:description',
  content
}, {
  name: 'twitter:description',
  content
}]);
exports.generateMetaDescriptionOptions = generateMetaDescriptionOptions;
const generateMetaTitleOptions = withContent(content => [{
  property: 'og:title',
  content
}, {
  name: 'twitter:title',
  content
}]);
exports.generateMetaTitleOptions = generateMetaTitleOptions;

const generateBrand = xs => xs ? `%s | ${xs}` : undefined;

exports.generateBrand = generateBrand;

const generateIcons = (site = {}) => site !== null && site !== void 0 && site.favicon ? [{
  src: site.favicon,
  sizes: '512x512',
  type: 'image/png'
}] : [];

exports.generateIcons = generateIcons;

const generateManifest = (site = {}) => ({
  background_color: site.color,
  description: site.description,
  display: 'fullscreen',
  icons: generateIcons(site),
  name: site.title,
  start_url: getStartUrl(),
  short_name: site.brand,
  theme_color: site.color
});

exports.generateManifest = generateManifest;

const Manifest = props => (0, _lodash.isObject)(props) ? /*#__PURE__*/_react.default.createElement("link", {
  rel: "manifest",
  href: `data:application/manifest+json,${encodeURIComponent(JSON.stringify(props))}`
}) : null;

exports.Manifest = Manifest;

const SEO = ({
  description,
  lang,
  meta,
  title
}) => {
  const site = (0, _useSiteMetaData.default)();
  const metaDescription = description || site.description;
  const metaTitle = title || site.title;
  return /*#__PURE__*/_react.default.createElement(_reactHelmet.Helmet, {
    htmlAttributes: {
      lang
    },
    title: metaTitle,
    titleTemplate: generateBrand((0, _lodash.get)(site, 'brand', 'Q3')),
    meta: [...generateMetaTitleOptions(metaTitle), ...generateMetaDescriptionOptions(metaDescription), {
      property: 'og:type',
      content: 'website'
    }, {
      name: 'twitter:card',
      content: 'summary'
    }].concat(meta)
  }, /*#__PURE__*/_react.default.createElement(Manifest, generateManifest(site)), /*#__PURE__*/_react.default.createElement("link", {
    rel: "icon",
    href: site.favicon
  }));
};

SEO.defaultProps = {
  lang: 'en',
  meta: [],
  description: '',
  title: ''
};
SEO.propTypes = {
  description: _propTypes.default.string,
  lang: _propTypes.default.string,
  meta: _propTypes.default.arrayOf(_propTypes.default.object),
  title: _propTypes.default.string
};
var _default = SEO;
exports.default = _default;